@@ -4,12 +4,14 @@
 @author: Jonathan Schilling (jonathan.schilling@ipp.mpg.de)
 @author: Caoxiang Zhu (czhu@pppl.gov)
 @author: Ksenia Aleynikova (ksenia.aleynikov@ipp.mpg.de)
+@author: Zhisong Qu (zhisong.qu@anu.edu.au)
 """
 
 import h5py
 import numpy as np  # for isscalar
 import os  # for path.abspath
 import keyword  # for getting python keywords
+SPEC_MAJOR_VERSION = 3.00
 
 # reader class for Stepped Pressure Equilibrium Code output file
 # S. Hudson et al., Physics of Plasmas 19, 112502 (2012); doi: 10.1063/1.4765691
@@ -34,9 +36,11 @@ class SPECout:
         metric,
         get_B,
         get_modB,
+        get_B_covariant,
+        test_derivatives
     )
     from ._plot_modB import plot_modB
-    from ._interface_current import interface_current, interface_current_total
+    from ._plot_iota import plot_iota
 
     def __init__(self, *args, **kwargs):
         # args[0] should always be the name of a file or an item inside the root object
@@ -50,6 +54,13 @@ class SPECout:
 
             # keep track of which file this object corresponds to
             self.filename = os.path.abspath(args[0])
+
+            # check version and print warning
+            try:
+                if _content['version'][()][0] < SPEC_MAJOR_VERSION:
+                    print("!!!Warning: this python package is used for SPEC!")
+            except KeyError:
+                print("!!!Warning: you might be not reading a SPEC HDF5 file!")
         elif isinstance(kwargs["content"], h5py.Group):
             _content = kwargs["content"]
 
@@ -80,6 +91,12 @@ class SPECout:
             # make sure that Lrad is always an array
             if np.isscalar(self.input.physics.Lrad):
                 self.input.physics.Lrad = np.array([self.input.physics.Lrad])
+            # make sure that im always an array
+            if np.isscalar(self.output.im):
+                self.output.im = np.array([self.output.im])
+            # make sure that in_ is always an array
+            if np.isscalar(self.output.in_):
+                self.output.in_ = np.array([self.output.in_])
 
             # these define the target dimensions in the radial direction
             Nvol = self.input.physics.Nvol
@@ -162,6 +179,7 @@ class SPECout:
                 self.poincare.Z = self.poincare.Z[self.poincare.success == 1, :, :]
                 self.poincare.t = self.poincare.t[self.poincare.success == 1, :, :]
                 self.poincare.s = self.poincare.s[self.poincare.success == 1, :, :]
+                
         return
 
     # needed for iterating over the contents of the file
